# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/trouver',
                'doc_host': 'https://hyunjongkimmath.github.io',
                'git_url': 'https://github.com/hyunjongkimmath/trouver',
                'lib_path': 'trouver'},
  'syms': { 'trouver.core': {'trouver.core.foo': ('core.html#foo', 'trouver/core.py')},
            'trouver.helper': { 'trouver.helper._init_replace_with_attributes': ( 'helper.html#_init_replace_with_attributes',
                                                                                  'trouver/helper.py'),
                                'trouver.helper._process_content': ('helper.html#_process_content', 'trouver/helper.py'),
                                'trouver.helper._select_replacement_text': ('helper.html#_select_replacement_text', 'trouver/helper.py'),
                                'trouver.helper._str_parts': ('helper.html#_str_parts', 'trouver/helper.py'),
                                'trouver.helper._test_directory': ('helper.html#_test_directory', 'trouver/helper.py'),
                                'trouver.helper.add_HTML_tag_data_to_raw_text': ( 'helper.html#add_html_tag_data_to_raw_text',
                                                                                  'trouver/helper.py'),
                                'trouver.helper.add_space_to_lt_symbols_without_space': ( 'helper.html#add_space_to_lt_symbols_without_space',
                                                                                          'trouver/helper.py'),
                                'trouver.helper.alphabet_or_latex_command_to_alphabet': ( 'helper.html#alphabet_or_latex_command_to_alphabet',
                                                                                          'trouver/helper.py'),
                                'trouver.helper.alphabet_or_latex_command_to_alphabet_group': ( 'helper.html#alphabet_or_latex_command_to_alphabet_group',
                                                                                                'trouver/helper.py'),
                                'trouver.helper.alphabet_to_alphabet_group': ( 'helper.html#alphabet_to_alphabet_group',
                                                                               'trouver/helper.py'),
                                'trouver.helper.containing_string_priority': ( 'helper.html#containing_string_priority',
                                                                               'trouver/helper.py'),
                                'trouver.helper.current_time_formatted_to_minutes': ( 'helper.html#current_time_formatted_to_minutes',
                                                                                      'trouver/helper.py'),
                                'trouver.helper.default_str_comparison': ('helper.html#default_str_comparison', 'trouver/helper.py'),
                                'trouver.helper.definition_asterisk_indices': ( 'helper.html#definition_asterisk_indices',
                                                                                'trouver/helper.py'),
                                'trouver.helper.defs_and_notats_separations': ( 'helper.html#defs_and_notats_separations',
                                                                                'trouver/helper.py'),
                                'trouver.helper.dict_with_keys_topologically_sorted': ( 'helper.html#dict_with_keys_topologically_sorted',
                                                                                        'trouver/helper.py'),
                                'trouver.helper.double_asterisk_indices': ('helper.html#double_asterisk_indices', 'trouver/helper.py'),
                                'trouver.helper.existing_path': ('helper.html#existing_path', 'trouver/helper.py'),
                                'trouver.helper.file_existence_test': ('helper.html#file_existence_test', 'trouver/helper.py'),
                                'trouver.helper.files_of_format_sorted': ('helper.html#files_of_format_sorted', 'trouver/helper.py'),
                                'trouver.helper.find_lt_symbols_without_space_in_math_mode': ( 'helper.html#find_lt_symbols_without_space_in_math_mode',
                                                                                               'trouver/helper.py'),
                                'trouver.helper.find_regex_in_text': ('helper.html#find_regex_in_text', 'trouver/helper.py'),
                                'trouver.helper.graph_for_topological_sort': ( 'helper.html#graph_for_topological_sort',
                                                                               'trouver/helper.py'),
                                'trouver.helper.html_tag_str': ('helper.html#html_tag_str', 'trouver/helper.py'),
                                'trouver.helper.inline_latex_indices': ('helper.html#inline_latex_indices', 'trouver/helper.py'),
                                'trouver.helper.is_number': ('helper.html#is_number', 'trouver/helper.py'),
                                'trouver.helper.latex_indices': ('helper.html#latex_indices', 'trouver/helper.py'),
                                'trouver.helper.natsort_comparison': ('helper.html#natsort_comparison', 'trouver/helper.py'),
                                'trouver.helper.notation_asterisk_indices': ('helper.html#notation_asterisk_indices', 'trouver/helper.py'),
                                'trouver.helper.path_name_no_ext': ('helper.html#path_name_no_ext', 'trouver/helper.py'),
                                'trouver.helper.path_no_ext': ('helper.html#path_no_ext', 'trouver/helper.py'),
                                'trouver.helper.remove_html_tags_in_text': ('helper.html#remove_html_tags_in_text', 'trouver/helper.py'),
                                'trouver.helper.replace_string_by_indices': ('helper.html#replace_string_by_indices', 'trouver/helper.py'),
                                'trouver.helper.separate_indices_from_str': ('helper.html#separate_indices_from_str', 'trouver/helper.py'),
                                'trouver.helper.text_from_file': ('helper.html#text_from_file', 'trouver/helper.py')},
            'trouver.helper.alphabet': { 'trouver.helper.alphabet.alphabet_or_latex_command_to_alphabet': ( 'helper.alphabet.html#alphabet_or_latex_command_to_alphabet',
                                                                                                            'trouver/helper/alphabet.py'),
                                         'trouver.helper.alphabet.alphabet_or_latex_command_to_alphabet_group': ( 'helper.alphabet.html#alphabet_or_latex_command_to_alphabet_group',
                                                                                                                  'trouver/helper/alphabet.py'),
                                         'trouver.helper.alphabet.alphabet_to_alphabet_group': ( 'helper.alphabet.html#alphabet_to_alphabet_group',
                                                                                                 'trouver/helper/alphabet.py')},
            'trouver.helper.arxiv': { 'trouver.helper.arxiv.ArxivMetadataEncoder': ( 'helper.arxiv.html#arxivmetadataencoder',
                                                                                     'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.ArxivMetadataEncoder.default': ( 'helper.arxiv.html#arxivmetadataencoder.default',
                                                                                             'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv._create_folder_for_source_download': ( 'helper.arxiv.html#_create_folder_for_source_download',
                                                                                                   'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv._download_pdf_with_name': ( 'helper.arxiv.html#_download_pdf_with_name',
                                                                                        'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv._download_source': ( 'helper.arxiv.html#_download_source',
                                                                                 'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv._unique_metadata_file_name': ( 'helper.arxiv.html#_unique_metadata_file_name',
                                                                                           'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.analyze_arxiv_tarfile': ( 'helper.arxiv.html#analyze_arxiv_tarfile',
                                                                                      'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.arxiv_id': ('helper.arxiv.html#arxiv_id', 'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.arxiv_search': ('helper.arxiv.html#arxiv_search', 'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.create_acronym': ( 'helper.arxiv.html#create_acronym',
                                                                               'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.download_from_results': ( 'helper.arxiv.html#download_from_results',
                                                                                      'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.extract_last_names': ( 'helper.arxiv.html#extract_last_names',
                                                                                   'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.extract_metadata': ( 'helper.arxiv.html#extract_metadata',
                                                                                 'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.extract_tex_from_gz': ( 'helper.arxiv.html#extract_tex_from_gz',
                                                                                    'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.file_name_for_pdf': ( 'helper.arxiv.html#file_name_for_pdf',
                                                                                  'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.folder_name_for_source': ( 'helper.arxiv.html#folder_name_for_source',
                                                                                       'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.get_tex_filename_from_gz': ( 'helper.arxiv.html#get_tex_filename_from_gz',
                                                                                         'trouver/helper/arxiv.py'),
                                      'trouver.helper.arxiv.read_gz_file': ('helper.arxiv.html#read_gz_file', 'trouver/helper/arxiv.py')},
            'trouver.helper.date_and_time': { 'trouver.helper.date_and_time.current_time_formatted_to_minutes': ( 'helper.date_and_time.html#current_time_formatted_to_minutes',
                                                                                                                  'trouver/helper/date_and_time.py')},
            'trouver.helper.definition_and_notation': { 'trouver.helper.definition_and_notation.definition_asterisk_indices': ( 'helper.definition_and_notation.html#definition_asterisk_indices',
                                                                                                                                'trouver/helper/definition_and_notation.py'),
                                                        'trouver.helper.definition_and_notation.defs_and_notats_separations': ( 'helper.definition_and_notation.html#defs_and_notats_separations',
                                                                                                                                'trouver/helper/definition_and_notation.py'),
                                                        'trouver.helper.definition_and_notation.double_asterisk_indices': ( 'helper.definition_and_notation.html#double_asterisk_indices',
                                                                                                                            'trouver/helper/definition_and_notation.py'),
                                                        'trouver.helper.definition_and_notation.notation_asterisk_indices': ( 'helper.definition_and_notation.html#notation_asterisk_indices',
                                                                                                                              'trouver/helper/definition_and_notation.py')},
            'trouver.helper.files_and_folders': { 'trouver.helper.files_and_folders.existing_path': ( 'helper.files_and_folders.html#existing_path',
                                                                                                      'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.file_existence_test': ( 'helper.files_and_folders.html#file_existence_test',
                                                                                                            'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.file_is_compressed': ( 'helper.files_and_folders.html#file_is_compressed',
                                                                                                           'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.files_of_format_sorted': ( 'helper.files_and_folders.html#files_of_format_sorted',
                                                                                                               'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.get_download_path': ( 'helper.files_and_folders.html#get_download_path',
                                                                                                          'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.get_huggingface_cache_dir': ( 'helper.files_and_folders.html#get_huggingface_cache_dir',
                                                                                                                  'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.path_name_no_ext': ( 'helper.files_and_folders.html#path_name_no_ext',
                                                                                                         'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.path_no_ext': ( 'helper.files_and_folders.html#path_no_ext',
                                                                                                    'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.text_from_file': ( 'helper.files_and_folders.html#text_from_file',
                                                                                                       'trouver/helper/files_and_folders.py'),
                                                  'trouver.helper.files_and_folders.uncompress_file': ( 'helper.files_and_folders.html#uncompress_file',
                                                                                                        'trouver/helper/files_and_folders.py')},
            'trouver.helper.html': { 'trouver.helper.html._init_replace_with_attributes': ( 'helper.html.html#_init_replace_with_attributes',
                                                                                            'trouver/helper/html.py'),
                                     'trouver.helper.html._process_content': ( 'helper.html.html#_process_content',
                                                                               'trouver/helper/html.py'),
                                     'trouver.helper.html._select_replacement_text': ( 'helper.html.html#_select_replacement_text',
                                                                                       'trouver/helper/html.py'),
                                     'trouver.helper.html.add_HTML_tag_data_to_raw_text': ( 'helper.html.html#add_html_tag_data_to_raw_text',
                                                                                            'trouver/helper/html.py'),
                                     'trouver.helper.html.add_space_to_lt_symbols_without_space': ( 'helper.html.html#add_space_to_lt_symbols_without_space',
                                                                                                    'trouver/helper/html.py'),
                                     'trouver.helper.html.find_lt_symbols_without_space_in_math_mode': ( 'helper.html.html#find_lt_symbols_without_space_in_math_mode',
                                                                                                         'trouver/helper/html.py'),
                                     'trouver.helper.html.html_tag_str': ('helper.html.html#html_tag_str', 'trouver/helper/html.py'),
                                     'trouver.helper.html.remove_html_tags_in_text': ( 'helper.html.html#remove_html_tags_in_text',
                                                                                       'trouver/helper/html.py')},
            'trouver.helper.latex': { 'trouver.helper.latex._detect_backslash_space_curly': ( 'helper.latex.html#_detect_backslash_space_curly',
                                                                                              'trouver/helper/latex.py'),
                                      'trouver.helper.latex._has_double_script': ( 'helper.latex.html#_has_double_script',
                                                                                   'trouver/helper/latex.py'),
                                      'trouver.helper.latex._has_invalid_left_right_bracket': ( 'helper.latex.html#_has_invalid_left_right_bracket',
                                                                                                'trouver/helper/latex.py'),
                                      'trouver.helper.latex._is_balanced_braces': ( 'helper.latex.html#_is_balanced_braces',
                                                                                    'trouver/helper/latex.py'),
                                      'trouver.helper.latex._is_left_right_balanced': ( 'helper.latex.html#_is_left_right_balanced',
                                                                                        'trouver/helper/latex.py'),
                                      'trouver.helper.latex._is_semantically_left_right_balanced': ( 'helper.latex.html#_is_semantically_left_right_balanced',
                                                                                                     'trouver/helper/latex.py'),
                                      'trouver.helper.latex.math_mode_string_is_syntactically_clean': ( 'helper.latex.html#math_mode_string_is_syntactically_clean',
                                                                                                        'trouver/helper/latex.py'),
                                      'trouver.helper.latex.math_mode_string_is_syntactically_valid': ( 'helper.latex.html#math_mode_string_is_syntactically_valid',
                                                                                                        'trouver/helper/latex.py'),
                                      'trouver.helper.latex.reduce_unnecessary_spaces': ( 'helper.latex.html#reduce_unnecessary_spaces',
                                                                                          'trouver/helper/latex.py')},
            'trouver.helper.latex.comments': { 'trouver.helper.latex.comments.remove_comments': ( 'helper.latex.comments.html#remove_comments',
                                                                                                  'trouver/helper/latex/comments.py')},
            'trouver.helper.latex.macros_and_commands': { 'trouver.helper.latex.macros_and_commands._argument_detection': ( 'helper.latex.macros_and_commands.html#_argument_detection',
                                                                                                                            'trouver/helper/latex/macros_and_commands.py'),
                                                          'trouver.helper.latex.macros_and_commands._commands_from_def': ( 'helper.latex.macros_and_commands.html#_commands_from_def',
                                                                                                                           'trouver/helper/latex/macros_and_commands.py'),
                                                          'trouver.helper.latex.macros_and_commands._commands_from_newcommand_and_declaremathoperator': ( 'helper.latex.macros_and_commands.html#_commands_from_newcommand_and_declaremathoperator',
                                                                                                                                                          'trouver/helper/latex/macros_and_commands.py'),
                                                          'trouver.helper.latex.macros_and_commands.custom_commands': ( 'helper.latex.macros_and_commands.html#custom_commands',
                                                                                                                        'trouver/helper/latex/macros_and_commands.py'),
                                                          'trouver.helper.latex.macros_and_commands.regex_pattern_detecting_command': ( 'helper.latex.macros_and_commands.html#regex_pattern_detecting_command',
                                                                                                                                        'trouver/helper/latex/macros_and_commands.py')},
            'trouver.helper.numbers': {'trouver.helper.numbers.is_number': ('helper.numbers.html#is_number', 'trouver/helper/numbers.py')},
            'trouver.helper.packages': { 'trouver.helper.packages.check_package_installed': ( 'star.html#check_package_installed',
                                                                                              'trouver/helper/packages.py'),
                                         'trouver.helper.packages.check_package_version_with_version_attribute': ( 'star.html#check_package_version_with_version_attribute',
                                                                                                                   'trouver/helper/packages.py'),
                                         'trouver.helper.packages.ensure_package_installed': ( 'star.html#ensure_package_installed',
                                                                                               'trouver/helper/packages.py'),
                                         'trouver.helper.packages.install_package': ( 'star.html#install_package',
                                                                                      'trouver/helper/packages.py')},
            'trouver.helper.path_accepted_string': { 'trouver.helper.path_accepted_string.latex_to_path_accepted_string': ( 'helper.path_accepted_string.html#latex_to_path_accepted_string',
                                                                                                                            'trouver/helper/path_accepted_string.py')},
            'trouver.helper.regex': { 'trouver.helper.regex._str_parts': ('helper.regex.html#_str_parts', 'trouver/helper/regex.py'),
                                      'trouver.helper.regex.find_regex_in_text': ( 'helper.regex.html#find_regex_in_text',
                                                                                   'trouver/helper/regex.py'),
                                      'trouver.helper.regex.inline_latex_indices': ( 'helper.regex.html#inline_latex_indices',
                                                                                     'trouver/helper/regex.py'),
                                      'trouver.helper.regex.latex_indices': ('helper.regex.html#latex_indices', 'trouver/helper/regex.py'),
                                      'trouver.helper.regex.replace_string_by_indices': ( 'helper.regex.html#replace_string_by_indices',
                                                                                          'trouver/helper/regex.py'),
                                      'trouver.helper.regex.separate_indices_from_str': ( 'helper.regex.html#separate_indices_from_str',
                                                                                          'trouver/helper/regex.py')},
            'trouver.helper.tests': { 'trouver.helper.tests._test_directory': ( 'helper.tests.html#_test_directory',
                                                                                'trouver/helper/tests.py')},
            'trouver.helper.topological_sort': { 'trouver.helper.topological_sort.containing_string_priority': ( 'helper.topological_sort.html#containing_string_priority',
                                                                                                                 'trouver/helper/topological_sort.py'),
                                                 'trouver.helper.topological_sort.default_str_comparison': ( 'helper.topological_sort.html#default_str_comparison',
                                                                                                             'trouver/helper/topological_sort.py'),
                                                 'trouver.helper.topological_sort.dict_with_keys_topologically_sorted': ( 'helper.topological_sort.html#dict_with_keys_topologically_sorted',
                                                                                                                          'trouver/helper/topological_sort.py'),
                                                 'trouver.helper.topological_sort.graph_for_topological_sort': ( 'helper.topological_sort.html#graph_for_topological_sort',
                                                                                                                 'trouver/helper/topological_sort.py'),
                                                 'trouver.helper.topological_sort.natsort_comparison': ( 'helper.topological_sort.html#natsort_comparison',
                                                                                                         'trouver/helper/topological_sort.py')},
            'trouver.latex.comments': { 'trouver.latex.comments.remove_comments': ( 'latex.comments.html#remove_comments',
                                                                                    'trouver/latex/comments.py')},
            'trouver.latex.convert': { 'trouver.latex.convert._adjust_common_section_titles_in_parts': ( 'latex.convert.html#_adjust_common_section_titles_in_parts',
                                                                                                         'trouver/latex/convert.py'),
                                       'trouver.latex.convert._adjusted_title': ( 'latex.convert.html#_adjusted_title',
                                                                                  'trouver/latex/convert.py'),
                                       'trouver.latex.convert._create_note_for_part': ( 'latex.convert.html#_create_note_for_part',
                                                                                        'trouver/latex/convert.py'),
                                       'trouver.latex.convert._create_notes_from_parts': ( 'latex.convert.html#_create_notes_from_parts',
                                                                                           'trouver/latex/convert.py'),
                                       'trouver.latex.convert._create_part_or_update': ( 'latex.convert.html#_create_part_or_update',
                                                                                         'trouver/latex/convert.py'),
                                       'trouver.latex.convert._highlight_latex_math': ( 'latex.convert.html#_highlight_latex_math',
                                                                                        'trouver/latex/convert.py'),
                                       'trouver.latex.convert._make_links_in_index_note_for_section': ( 'latex.convert.html#_make_links_in_index_note_for_section',
                                                                                                        'trouver/latex/convert.py'),
                                       'trouver.latex.convert._make_links_in_index_notes': ( 'latex.convert.html#_make_links_in_index_notes',
                                                                                             'trouver/latex/convert.py'),
                                       'trouver.latex.convert._replace_custom_commands_in_parts': ( 'latex.convert.html#_replace_custom_commands_in_parts',
                                                                                                    'trouver/latex/convert.py'),
                                       'trouver.latex.convert._replace_html_with_latex_command_markings': ( 'latex.convert.html#_replace_html_with_latex_command_markings',
                                                                                                            'trouver/latex/convert.py'),
                                       'trouver.latex.convert._text_to_replace_html_with': ( 'latex.convert.html#_text_to_replace_html_with',
                                                                                             'trouver/latex/convert.py'),
                                       'trouver.latex.convert._update_links_to_make': ( 'latex.convert.html#_update_links_to_make',
                                                                                        'trouver/latex/convert.py'),
                                       'trouver.latex.convert.convert_notes_to_latex_code': ( 'latex.convert.html#convert_notes_to_latex_code',
                                                                                              'trouver/latex/convert.py'),
                                       'trouver.latex.convert.setup_reference_from_latex_parts': ( 'latex.convert.html#setup_reference_from_latex_parts',
                                                                                                   'trouver/latex/convert.py')},
            'trouver.latex.divide': { 'trouver.latex.divide.NoDocumentNodeError': ( 'latex.divide.html#nodocumentnodeerror',
                                                                                    'trouver/latex/divide.py'),
                                      'trouver.latex.divide.NoDocumentNodeError.__init__': ( 'latex.divide.html#nodocumentnodeerror.__init__',
                                                                                             'trouver/latex/divide.py'),
                                      'trouver.latex.divide._append_non_environment_accumulation_to_parts_if_non_empty': ( 'latex.divide.html#_append_non_environment_accumulation_to_parts_if_non_empty',
                                                                                                                           'trouver/latex/divide.py'),
                                      'trouver.latex.divide._article_is_amsart_or_article': ( 'latex.divide.html#_article_is_amsart_or_article',
                                                                                              'trouver/latex/divide.py'),
                                      'trouver.latex.divide._change_counters': ( 'latex.divide.html#_change_counters',
                                                                                 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._change_counters_antecedently': ( 'latex.divide.html#_change_counters_antecedently',
                                                                                              'trouver/latex/divide.py'),
                                      'trouver.latex.divide._combine_second_and_third_paramter_results': ( 'latex.divide.html#_combine_second_and_third_paramter_results',
                                                                                                           'trouver/latex/divide.py'),
                                      'trouver.latex.divide._environment_name_of_text': ( 'latex.divide.html#_environment_name_of_text',
                                                                                          'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_environment_node': ( 'latex.divide.html#_is_environment_node',
                                                                                     'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_numbered': ('latex.divide.html#_is_numbered', 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_numberedwithin': ( 'latex.divide.html#_is_numberedwithin',
                                                                                   'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_section_node': ( 'latex.divide.html#_is_section_node',
                                                                                 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_subsection_node': ( 'latex.divide.html#_is_subsection_node',
                                                                                    'trouver/latex/divide.py'),
                                      'trouver.latex.divide._is_subsubsection_node': ( 'latex.divide.html#_is_subsubsection_node',
                                                                                       'trouver/latex/divide.py'),
                                      'trouver.latex.divide._node_is_nonspecial_following_a_sectionlike_node': ( 'latex.divide.html#_node_is_nonspecial_following_a_sectionlike_node',
                                                                                                                 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._node_is_proof_immediately_following_a_theorem_like_environment': ( 'latex.divide.html#_node_is_proof_immediately_following_a_theorem_like_environment',
                                                                                                                                'trouver/latex/divide.py'),
                                      'trouver.latex.divide._node_numbering': ( 'latex.divide.html#_node_numbering',
                                                                                'trouver/latex/divide.py'),
                                      'trouver.latex.divide._node_warrants_own_part': ( 'latex.divide.html#_node_warrants_own_part',
                                                                                        'trouver/latex/divide.py'),
                                      'trouver.latex.divide._numbering_helper': ( 'latex.divide.html#_numbering_helper',
                                                                                  'trouver/latex/divide.py'),
                                      'trouver.latex.divide._process_node': ('latex.divide.html#_process_node', 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._search_counters_by_pattern': ( 'latex.divide.html#_search_counters_by_pattern',
                                                                                            'trouver/latex/divide.py'),
                                      'trouver.latex.divide._search_display_names_by_pattern': ( 'latex.divide.html#_search_display_names_by_pattern',
                                                                                                 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._section_title': ( 'latex.divide.html#_section_title',
                                                                               'trouver/latex/divide.py'),
                                      'trouver.latex.divide._setup_all_numberwithins': ( 'latex.divide.html#_setup_all_numberwithins',
                                                                                         'trouver/latex/divide.py'),
                                      'trouver.latex.divide._setup_counters': ( 'latex.divide.html#_setup_counters',
                                                                                'trouver/latex/divide.py'),
                                      'trouver.latex.divide._setup_numberwithins': ( 'latex.divide.html#_setup_numberwithins',
                                                                                     'trouver/latex/divide.py'),
                                      'trouver.latex.divide._subsubnodes': ('latex.divide.html#_subsubnodes', 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._text_is_of_environment_node': ( 'latex.divide.html#_text_is_of_environment_node',
                                                                                             'trouver/latex/divide.py'),
                                      'trouver.latex.divide._text_is_of_section_like_node': ( 'latex.divide.html#_text_is_of_section_like_node',
                                                                                              'trouver/latex/divide.py'),
                                      'trouver.latex.divide._title': ('latex.divide.html#_title', 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._title_for_environment_node': ( 'latex.divide.html#_title_for_environment_node',
                                                                                            'trouver/latex/divide.py'),
                                      'trouver.latex.divide._title_for_section_subsection_subsubsection_node': ( 'latex.divide.html#_title_for_section_subsection_subsubsection_node',
                                                                                                                 'trouver/latex/divide.py'),
                                      'trouver.latex.divide._unnumbered_environments': ( 'latex.divide.html#_unnumbered_environments',
                                                                                         'trouver/latex/divide.py'),
                                      'trouver.latex.divide._update_counter_for_subsubnodes': ( 'latex.divide.html#_update_counter_for_subsubnodes',
                                                                                                'trouver/latex/divide.py'),
                                      'trouver.latex.divide.display_names_of_environments': ( 'latex.divide.html#display_names_of_environments',
                                                                                              'trouver/latex/divide.py'),
                                      'trouver.latex.divide.divide_latex_text': ( 'latex.divide.html#divide_latex_text',
                                                                                  'trouver/latex/divide.py'),
                                      'trouver.latex.divide.environment_names_used': ( 'latex.divide.html#environment_names_used',
                                                                                       'trouver/latex/divide.py'),
                                      'trouver.latex.divide.find_document_node': ( 'latex.divide.html#find_document_node',
                                                                                   'trouver/latex/divide.py'),
                                      'trouver.latex.divide.get_node_from_simple_text': ( 'latex.divide.html#get_node_from_simple_text',
                                                                                          'trouver/latex/divide.py'),
                                      'trouver.latex.divide.numbered_newtheorems_counters_in_preamble': ( 'latex.divide.html#numbered_newtheorems_counters_in_preamble',
                                                                                                          'trouver/latex/divide.py'),
                                      'trouver.latex.divide.numberwithins_in_preamble': ( 'latex.divide.html#numberwithins_in_preamble',
                                                                                          'trouver/latex/divide.py'),
                                      'trouver.latex.divide.swap_numbers_invoked': ( 'latex.divide.html#swap_numbers_invoked',
                                                                                     'trouver/latex/divide.py'),
                                      'trouver.latex.divide.text_from_node': ( 'latex.divide.html#text_from_node',
                                                                               'trouver/latex/divide.py')},
            'trouver.latex.folders': { 'trouver.latex.folders._consider_part_to_add': ( 'latex.folders.html#_consider_part_to_add',
                                                                                        'trouver/latex/folders.py'),
                                       'trouver.latex.folders._part_starts_section': ( 'latex.folders.html#_part_starts_section',
                                                                                       'trouver/latex/folders.py'),
                                       'trouver.latex.folders._part_starts_subsection': ( 'latex.folders.html#_part_starts_subsection',
                                                                                          'trouver/latex/folders.py'),
                                       'trouver.latex.folders.section_and_subsection_titles_from_latex_parts': ( 'latex.folders.html#section_and_subsection_titles_from_latex_parts',
                                                                                                                 'trouver/latex/folders.py')},
            'trouver.latex.formatting': { 'trouver.latex.formatting._ends_with_less_than_two_newlines': ( 'latex.formatting.html#_ends_with_less_than_two_newlines',
                                                                                                          'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._inline_mathmode_to_own_paragraph': ( 'latex.formatting.html#_inline_mathmode_to_own_paragraph',
                                                                                                          'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._is_special_line': ( 'latex.formatting.html#_is_special_line',
                                                                                         'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._make_end_with_two_newlines': ( 'latex.formatting.html#_make_end_with_two_newlines',
                                                                                                    'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._make_start_with_two_newlines': ( 'latex.formatting.html#_make_start_with_two_newlines',
                                                                                                      'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._merge_multilines': ( 'latex.formatting.html#_merge_multilines',
                                                                                          'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._merge_multilines_for_non_mathmode_part': ( 'latex.formatting.html#_merge_multilines_for_non_mathmode_part',
                                                                                                                'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._remove_ensuremath': ( 'latex.formatting.html#_remove_ensuremath',
                                                                                           'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._remove_one_blank_space_if_exists': ( 'latex.formatting.html#_remove_one_blank_space_if_exists',
                                                                                                          'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._remove_xspace': ( 'latex.formatting.html#_remove_xspace',
                                                                                       'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._replace_backtick_and_apostrophe_quotes': ( 'latex.formatting.html#_replace_backtick_and_apostrophe_quotes',
                                                                                                                'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._replace_command': ( 'latex.formatting.html#_replace_command',
                                                                                         'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._replace_ensuremath': ( 'latex.formatting.html#_replace_ensuremath',
                                                                                            'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._replace_equationlike_envs': ( 'latex.formatting.html#_replace_equationlike_envs',
                                                                                                   'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._replace_math_mode_delimiters': ( 'latex.formatting.html#_replace_math_mode_delimiters',
                                                                                                      'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._separate_inline_latex': ( 'latex.formatting.html#_separate_inline_latex',
                                                                                               'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._starts_with_less_than_two_newlines': ( 'latex.formatting.html#_starts_with_less_than_two_newlines',
                                                                                                            'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting._strip_and_return_whitespaces': ( 'latex.formatting.html#_strip_and_return_whitespaces',
                                                                                                      'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.adjust_common_syntax_to_markdown': ( 'latex.formatting.html#adjust_common_syntax_to_markdown',
                                                                                                         'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.is_number': ( 'latex.formatting.html#is_number',
                                                                                  'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.remove_dollar_signs_around_equationlike_envs': ( 'latex.formatting.html#remove_dollar_signs_around_equationlike_envs',
                                                                                                                     'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.replace_command_in_text': ( 'latex.formatting.html#replace_command_in_text',
                                                                                                'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.replace_commands_in_latex_document': ( 'latex.formatting.html#replace_commands_in_latex_document',
                                                                                                           'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.replace_commands_in_text': ( 'latex.formatting.html#replace_commands_in_text',
                                                                                                 'trouver/latex/formatting.py'),
                                          'trouver.latex.formatting.replace_input_and_include': ( 'latex.formatting.html#replace_input_and_include',
                                                                                                  'trouver/latex/formatting.py')},
            'trouver.latex.preamble': { 'trouver.latex.preamble.divide_preamble': ( 'latex.preamble.html#divide_preamble',
                                                                                    'trouver/latex/preamble.py'),
                                        'trouver.latex.preamble.replace_inclusion_of_style_file_with_code': ( 'latex.preamble.html#replace_inclusion_of_style_file_with_code',
                                                                                                              'trouver/latex/preamble.py')},
            'trouver.markdown.markdown.file': { 'trouver.markdown.markdown.file.MarkdownFile': ( 'markdown.markdown.file.html#markdownfile',
                                                                                                 'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.__init__': ( 'markdown.markdown.file.html#markdownfile.__init__',
                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.__str__': ( 'markdown.markdown.file.html#markdownfile.__str__',
                                                                                                         'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._include_previous_line_as_id_text': ( 'markdown.markdown.file.html#markdownfile._include_previous_line_as_id_text',
                                                                                                                                   'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._line_dict': ( 'markdown.markdown.file.html#markdownfile._line_dict',
                                                                                                            'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._look_at_start_of_file': ( 'markdown.markdown.file.html#markdownfile._look_at_start_of_file',
                                                                                                                        'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._merge_latex_into_text': ( 'markdown.markdown.file.html#markdownfile._merge_latex_into_text',
                                                                                                                        'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._merge_one_display_math_mode_latex_chunk': ( 'markdown.markdown.file.html#markdownfile._merge_one_display_math_mode_latex_chunk',
                                                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._replace_embedded_links_one_line': ( 'markdown.markdown.file.html#markdownfile._replace_embedded_links_one_line',
                                                                                                                                  'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._text_of_embedded_link_of_id': ( 'markdown.markdown.file.html#markdownfile._text_of_embedded_link_of_id',
                                                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._text_of_embedded_link_of_section': ( 'markdown.markdown.file.html#markdownfile._text_of_embedded_link_of_section',
                                                                                                                                   'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile._text_of_lines_of_embedded_links': ( 'markdown.markdown.file.html#markdownfile._text_of_lines_of_embedded_links',
                                                                                                                                  'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.add_blank_line_to_end': ( 'markdown.markdown.file.html#markdownfile.add_blank_line_to_end',
                                                                                                                       'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.add_line_in_section': ( 'markdown.markdown.file.html#markdownfile.add_line_in_section',
                                                                                                                     'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.add_line_to_end': ( 'markdown.markdown.file.html#markdownfile.add_line_to_end',
                                                                                                                 'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.add_metadata_section': ( 'markdown.markdown.file.html#markdownfile.add_metadata_section',
                                                                                                                      'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.add_tags': ( 'markdown.markdown.file.html#markdownfile.add_tags',
                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.clear_all_sections': ( 'markdown.markdown.file.html#markdownfile.clear_all_sections',
                                                                                                                    'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.clear_section': ( 'markdown.markdown.file.html#markdownfile.clear_section',
                                                                                                               'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.copy': ( 'markdown.markdown.file.html#markdownfile.copy',
                                                                                                      'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.from_file': ( 'markdown.markdown.file.html#markdownfile.from_file',
                                                                                                           'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.from_list': ( 'markdown.markdown.file.html#markdownfile.from_list',
                                                                                                           'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.from_string': ( 'markdown.markdown.file.html#markdownfile.from_string',
                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.from_vault_note': ( 'markdown.markdown.file.html#markdownfile.from_vault_note',
                                                                                                                 'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_headings': ( 'markdown.markdown.file.html#markdownfile.get_headings',
                                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_headings_and_text': ( 'markdown.markdown.file.html#markdownfile.get_headings_and_text',
                                                                                                                       'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_headings_by_line_number': ( 'markdown.markdown.file.html#markdownfile.get_headings_by_line_number',
                                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_headings_tree': ( 'markdown.markdown.file.html#markdownfile.get_headings_tree',
                                                                                                                   'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_line_number_of_heading': ( 'markdown.markdown.file.html#markdownfile.get_line_number_of_heading',
                                                                                                                            'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.get_line_numbers_under_heading': ( 'markdown.markdown.file.html#markdownfile.get_line_numbers_under_heading',
                                                                                                                                'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.has_metadata': ( 'markdown.markdown.file.html#markdownfile.has_metadata',
                                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.has_tag': ( 'markdown.markdown.file.html#markdownfile.has_tag',
                                                                                                         'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.insert_line': ( 'markdown.markdown.file.html#markdownfile.insert_line',
                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.merge_display_math_mode': ( 'markdown.markdown.file.html#markdownfile.merge_display_math_mode',
                                                                                                                         'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.merge_display_math_mode_into_preceding_text': ( 'markdown.markdown.file.html#markdownfile.merge_display_math_mode_into_preceding_text',
                                                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.metadata': ( 'markdown.markdown.file.html#markdownfile.metadata',
                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.metadata_lines': ( 'markdown.markdown.file.html#markdownfile.metadata_lines',
                                                                                                                'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.metadata_parts': ( 'markdown.markdown.file.html#markdownfile.metadata_parts',
                                                                                                                'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.parts_of_id': ( 'markdown.markdown.file.html#markdownfile.parts_of_id',
                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.pop_line': ( 'markdown.markdown.file.html#markdownfile.pop_line',
                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_double_blank_lines': ( 'markdown.markdown.file.html#markdownfile.remove_double_blank_lines',
                                                                                                                           'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_footnotes_to_embedded_links': ( 'markdown.markdown.file.html#markdownfile.remove_footnotes_to_embedded_links',
                                                                                                                                    'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_headers': ( 'markdown.markdown.file.html#markdownfile.remove_headers',
                                                                                                                'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_html_tags': ( 'markdown.markdown.file.html#markdownfile.remove_html_tags',
                                                                                                                  'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_in_line_tags': ( 'markdown.markdown.file.html#markdownfile.remove_in_line_tags',
                                                                                                                     'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_line': ( 'markdown.markdown.file.html#markdownfile.remove_line',
                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_lines': ( 'markdown.markdown.file.html#markdownfile.remove_lines',
                                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_metadata': ( 'markdown.markdown.file.html#markdownfile.remove_metadata',
                                                                                                                 'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_section': ( 'markdown.markdown.file.html#markdownfile.remove_section',
                                                                                                                'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.remove_tags': ( 'markdown.markdown.file.html#markdownfile.remove_tags',
                                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.replace_auto_tags_with_regular_tags': ( 'markdown.markdown.file.html#markdownfile.replace_auto_tags_with_regular_tags',
                                                                                                                                     'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.replace_embedded_links_with_text': ( 'markdown.markdown.file.html#markdownfile.replace_embedded_links_with_text',
                                                                                                                                  'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.replace_links_with_display_text': ( 'markdown.markdown.file.html#markdownfile.replace_links_with_display_text',
                                                                                                                                 'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.replace_metadata': ( 'markdown.markdown.file.html#markdownfile.replace_metadata',
                                                                                                                  'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.text_of_lines': ( 'markdown.markdown.file.html#markdownfile.text_of_lines',
                                                                                                               'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownFile.write': ( 'markdown.markdown.file.html#markdownfile.write',
                                                                                                       'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.MarkdownLineEnum': ( 'markdown.markdown.file.html#markdownlineenum',
                                                                                                     'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._enquote': ( 'markdown.markdown.file.html#_enquote',
                                                                                             'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._line_end_in_line_latex': ( 'markdown.markdown.file.html#_line_end_in_line_latex',
                                                                                                            'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._line_start_and_end_in_line_latex': ( 'markdown.markdown.file.html#_line_start_and_end_in_line_latex',
                                                                                                                      'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._line_start_in_line_latex': ( 'markdown.markdown.file.html#_line_start_in_line_latex',
                                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._line_str': ( 'markdown.markdown.file.html#_line_str',
                                                                                              'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file._remove_text_id': ( 'markdown.markdown.file.html#_remove_text_id',
                                                                                                    'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.dict_to_metadata_lines': ( 'markdown.markdown.file.html#dict_to_metadata_lines',
                                                                                                           'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.find_front_matter_meta_in_markdown_text': ( 'markdown.markdown.file.html#find_front_matter_meta_in_markdown_text',
                                                                                                                            'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.parse_metadata_string': ( 'markdown.markdown.file.html#parse_metadata_string',
                                                                                                          'trouver/markdown/markdown/file.py'),
                                                'trouver.markdown.markdown.file.replace_embedded_links_with_text': ( 'markdown.markdown.file.html#replace_embedded_links_with_text',
                                                                                                                     'trouver/markdown/markdown/file.py')},
            'trouver.markdown.markdown.heading': { 'trouver.markdown.markdown.heading.heading_level': ( 'markdown.markdown.heading.html#heading_level',
                                                                                                        'trouver/markdown/markdown/heading.py'),
                                                   'trouver.markdown.markdown.heading.heading_title': ( 'markdown.markdown.heading.html#heading_title',
                                                                                                        'trouver/markdown/markdown/heading.py')},
            'trouver.markdown.obsidian.footnotes': { 'trouver.markdown.obsidian.footnotes.embedded_note_of_footnote': ( 'markdown.obsidian.footnotes.html#embedded_note_of_footnote',
                                                                                                                        'trouver/markdown/obsidian/footnotes.py'),
                                                     'trouver.markdown.obsidian.footnotes.find_footnote_descriptions_in_markdown_text': ( 'markdown.obsidian.footnotes.html#find_footnote_descriptions_in_markdown_text',
                                                                                                                                          'trouver/markdown/obsidian/footnotes.py'),
                                                     'trouver.markdown.obsidian.footnotes.find_footnote_mentions_in_markdown_text': ( 'markdown.obsidian.footnotes.html#find_footnote_mentions_in_markdown_text',
                                                                                                                                      'trouver/markdown/obsidian/footnotes.py'),
                                                     'trouver.markdown.obsidian.footnotes.footnote_is_simple_embedded_note': ( 'markdown.obsidian.footnotes.html#footnote_is_simple_embedded_note',
                                                                                                                               'trouver/markdown/obsidian/footnotes.py'),
                                                     'trouver.markdown.obsidian.footnotes.remove_footnote_mentions_in_markdown_text': ( 'markdown.obsidian.footnotes.html#remove_footnote_mentions_in_markdown_text',
                                                                                                                                        'trouver/markdown/obsidian/footnotes.py')},
            'trouver.markdown.obsidian.links': { 'trouver.markdown.obsidian.links.LinkFormatError': ( 'markdown.obsidian.links.html#linkformaterror',
                                                                                                      'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.LinkFormatError.__init__': ( 'markdown.obsidian.links.html#linkformaterror.__init__',
                                                                                                               'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.LinkType': ( 'markdown.obsidian.links.html#linktype',
                                                                                               'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink': ( 'markdown.obsidian.links.html#obsidianlink',
                                                                                                   'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.__copy__': ( 'markdown.obsidian.links.html#obsidianlink.__copy__',
                                                                                                            'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.__eq__': ( 'markdown.obsidian.links.html#obsidianlink.__eq__',
                                                                                                          'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.__hash__': ( 'markdown.obsidian.links.html#obsidianlink.__hash__',
                                                                                                            'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.__init__': ( 'markdown.obsidian.links.html#obsidianlink.__init__',
                                                                                                            'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.__str__': ( 'markdown.obsidian.links.html#obsidianlink.__str__',
                                                                                                           'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink._parse_text_as_wikilink': ( 'markdown.obsidian.links.html#obsidianlink._parse_text_as_wikilink',
                                                                                                                           'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.convert_link_type': ( 'markdown.obsidian.links.html#obsidianlink.convert_link_type',
                                                                                                                     'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.displayed_text': ( 'markdown.obsidian.links.html#obsidianlink.displayed_text',
                                                                                                                  'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.from_text': ( 'markdown.obsidian.links.html#obsidianlink.from_text',
                                                                                                             'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.is_abstract': ( 'markdown.obsidian.links.html#obsidianlink.is_abstract',
                                                                                                               'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.to_regex': ( 'markdown.obsidian.links.html#obsidianlink.to_regex',
                                                                                                            'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.ObsidianLink.to_string': ( 'markdown.obsidian.links.html#obsidianlink.to_string',
                                                                                                             'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links._do_not_remove_link': ( 'markdown.obsidian.links.html#_do_not_remove_link',
                                                                                                          'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.link_ranges_in_text': ( 'markdown.obsidian.links.html#link_ranges_in_text',
                                                                                                          'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.links_from_text': ( 'markdown.obsidian.links.html#links_from_text',
                                                                                                      'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.remove_links_from_text': ( 'markdown.obsidian.links.html#remove_links_from_text',
                                                                                                             'trouver/markdown/obsidian/links.py'),
                                                 'trouver.markdown.obsidian.links.replace_links_in_text': ( 'markdown.obsidian.links.html#replace_links_in_text',
                                                                                                            'trouver/markdown/obsidian/links.py')},
            'trouver.markdown.obsidian.personal.authors': { 'trouver.markdown.obsidian.personal.authors.find_author_file': ( 'markdown.obisidian.personal.authors.html#find_author_file',
                                                                                                                             'trouver/markdown/obsidian/personal/authors.py'),
                                                            'trouver.markdown.obsidian.personal.authors.just_last_name': ( 'markdown.obisidian.personal.authors.html#just_last_name',
                                                                                                                           'trouver/markdown/obsidian/personal/authors.py')},
            'trouver.markdown.obsidian.personal.index_notes': { 'trouver.markdown.obsidian.personal.index_notes._move_notes_under_heading': ( 'markdown.obsidian.personal.index_notes.html#_move_notes_under_heading',
                                                                                                                                              'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.add_link_in_index_note_after_note_link': ( 'markdown.obsidian.personal.index_notes.html#add_link_in_index_note_after_note_link',
                                                                                                                                                           'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.convert_heading_to_folder_name': ( 'markdown.obsidian.personal.index_notes.html#convert_heading_to_folder_name',
                                                                                                                                                   'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.convert_title_to_folder_name': ( 'markdown.obsidian.personal.index_notes.html#convert_title_to_folder_name',
                                                                                                                                                 'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.correspond_headings_with_folder': ( 'markdown.obsidian.personal.index_notes.html#correspond_headings_with_folder',
                                                                                                                                                    'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.get_alphanumeric': ( 'markdown.obsidian.personal.index_notes.html#get_alphanumeric',
                                                                                                                                     'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.get_notes_from_index_note': ( 'markdown.obsidian.personal.index_notes.html#get_notes_from_index_note',
                                                                                                                                              'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.information_notes_linked_in_index_note': ( 'markdown.obsidian.personal.index_notes.html#information_notes_linked_in_index_note',
                                                                                                                                                           'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.make_folders_from_index_note_headers': ( 'markdown.obsidian.personal.index_notes.html#make_folders_from_index_note_headers',
                                                                                                                                                         'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.move_information_notes_to_correct_folder': ( 'markdown.obsidian.personal.index_notes.html#move_information_notes_to_correct_folder',
                                                                                                                                                             'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.move_information_notes_to_correct_folder_for_all_indices': ( 'markdown.obsidian.personal.index_notes.html#move_information_notes_to_correct_folder_for_all_indices',
                                                                                                                                                                             'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.subsection_folders': ( 'markdown.obsidian.personal.index_notes.html#subsection_folders',
                                                                                                                                       'trouver/markdown/obsidian/personal/index_notes.py'),
                                                                'trouver.markdown.obsidian.personal.index_notes.subsections_listed_in_index_note': ( 'markdown.obsidian.personal.index_notes.html#subsections_listed_in_index_note',
                                                                                                                                                     'trouver/markdown/obsidian/personal/index_notes.py')},
            'trouver.markdown.obsidian.personal.information_notes': { 'trouver.markdown.obsidian.personal.information_notes._index_note_in_parent_directory': ( 'markdown.obsidian.personal.information_notes.html#_index_note_in_parent_directory',
                                                                                                                                                                'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes._index_note_in_same_directory': ( 'markdown.obsidian.personal.information_notes.html#_index_note_in_same_directory',
                                                                                                                                                              'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes._note_is_not_linked_in_index_note': ( 'markdown.obsidian.personal.information_notes.html#_note_is_not_linked_in_index_note',
                                                                                                                                                                  'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.bulleted_links_of_type_in_section': ( 'markdown.obsidian.personal.information_notes.html#bulleted_links_of_type_in_section',
                                                                                                                                                                  'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.citation_location_string': ( 'markdown.obsidian.personal.information_notes.html#citation_location_string',
                                                                                                                                                         'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.create_generic_info_notes_and_link_to_index': ( 'markdown.obsidian.personal.information_notes.html#create_generic_info_notes_and_link_to_index',
                                                                                                                                                                            'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.create_info_notes_and_link_to_index': ( 'markdown.obsidian.personal.information_notes.html#create_info_notes_and_link_to_index',
                                                                                                                                                                    'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.fill_info_note_with_template': ( 'markdown.obsidian.personal.information_notes.html#fill_info_note_with_template',
                                                                                                                                                             'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.index_note_of_a_directory': ( 'markdown.obsidian.personal.information_notes.html#index_note_of_a_directory',
                                                                                                                                                          'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.index_note_of_note': ( 'markdown.obsidian.personal.information_notes.html#index_note_of_note',
                                                                                                                                                   'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.link_info_notes_to_index': ( 'markdown.obsidian.personal.information_notes.html#link_info_notes_to_index',
                                                                                                                                                         'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.links_to_common_terms_notes_in_see_also_section': ( 'markdown.obsidian.personal.information_notes.html#links_to_common_terms_notes_in_see_also_section',
                                                                                                                                                                                'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.main_content': ( 'markdown.obsidian.personal.information_notes.html#main_content',
                                                                                                                                             'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.reference_notes_in_references_section_of_information_note': ( 'markdown.obsidian.personal.information_notes.html#reference_notes_in_references_section_of_information_note',
                                                                                                                                                                                          'trouver/markdown/obsidian/personal/information_notes.py'),
                                                                      'trouver.markdown.obsidian.personal.information_notes.reference_of_information_note': ( 'markdown.obsidian.personal.information_notes.html#reference_of_information_note',
                                                                                                                                                              'trouver/markdown/obsidian/personal/information_notes.py')},
            'trouver.markdown.obsidian.personal.machine_learning.database_update': { 'trouver.markdown.obsidian.personal.machine_learning.database_update.append_to_database': ( 'markdown.obsidian.personal.machine_learninig.database_update.html#append_to_database',
                                                                                                                                                                                 'trouver/markdown/obsidian/personal/machine_learning/database_update.py'),
                                                                                     'trouver.markdown.obsidian.personal.machine_learning.database_update.max_ID': ( 'markdown.obsidian.personal.machine_learninig.database_update.html#max_id',
                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/database_update.py')},
            'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming': { 'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming._correct_syntax': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#_correct_syntax',
                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming._name_prediction_for_data_point': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#_name_prediction_for_data_point',
                                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.add_autogen_name_to_notation_note': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#add_autogen_name_to_notation_note',
                                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.add_names_to_html_tags_in_info_note': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#add_names_to_html_tags_in_info_note',
                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.autogen_name_from_notation_note': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#autogen_name_from_notation_note',
                                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.data_from_information_note': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#data_from_information_note',
                                                                                                                                                                                                                       'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.predict_name_and_add_to_notation_note': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#predict_name_and_add_to_notation_note',
                                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.predict_names': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#predict_names',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py'),
                                                                                                    'trouver.markdown.obsidian.personal.machine_learning.definition_and_notation_naming.sanitize_autogen_name': ( 'markdown.obsidian.personal.machine_learning.definition_and_notation_naming.html#sanitize_autogen_name',
                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/definition_and_notation_naming.py')},
            'trouver.markdown.obsidian.personal.machine_learning.definition_identification': { 'trouver.markdown.obsidian.personal.machine_learning.definition_identification.definition_identification_data_from_note': ( 'markdown.obsidian.personal.machine_learning.definition_identification.html#definition_identification_data_from_note',
                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/definition_identification.py'),
                                                                                               'trouver.markdown.obsidian.personal.machine_learning.definition_identification.definitions_in_text': ( 'markdown.obsidian.personal.machine_learning.definition_identification.html#definitions_in_text',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/definition_identification.py'),
                                                                                               'trouver.markdown.obsidian.personal.machine_learning.definition_identification.gather_definition_identification_data': ( 'markdown.obsidian.personal.machine_learning.definition_identification.html#gather_definition_identification_data',
                                                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/definition_identification.py')},
            'trouver.markdown.obsidian.personal.machine_learning.information_note_types': { 'trouver.markdown.obsidian.personal.machine_learning.information_note_types._append_single_predicted_tag': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_append_single_predicted_tag',
                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._auto_prediction': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_auto_prediction',
                                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._change_label_tags_for_single_note': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_change_label_tags_for_single_note',
                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._has_any_label_tags': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_has_any_label_tags',
                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._has_exactly_predicted_tags': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_has_exactly_predicted_tags',
                                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._make_probability_dict': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_make_probability_dict',
                                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types._transpose_list': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#_transpose_list',
                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.append_to_information_note_type_database': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#append_to_information_note_type_database',
                                                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.automatically_add_note_type_tags': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#automatically_add_note_type_tags',
                                                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.consolidate_single_text_predictions_by_sum_of_confidence': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#consolidate_single_text_predictions_by_sum_of_confidence',
                                                                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.convert_auto_tags_to_regular_tags_in_notes': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#convert_auto_tags_to_regular_tags_in_notes',
                                                                                                                                                                                                                       'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.gather_information_note_types': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#gather_information_note_types',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.information_note_types_as_dataset': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#information_note_types_as_dataset',
                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.labels_and_identifying_info_from_notes': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#labels_and_identifying_info_from_notes',
                                                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.note_is_labeled_with_tag': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#note_is_labeled_with_tag',
                                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.note_labels': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#note_labels',
                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.possible_text_type_labels': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#possible_text_type_labels',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.predict_note_types': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#predict_note_types',
                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.information_note_types.predict_text_types_with_one_learner': ( 'markdown.obsidian.personal.machine_learning.information_note_types.html#predict_text_types_with_one_learner',
                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/information_note_types.py')},
            'trouver.markdown.obsidian.personal.machine_learning.notation': { 'trouver.markdown.obsidian.personal.machine_learning.notation._get_notation_indices_to_add': ( 'markdown.obsidian.personal.machine_learning.notation.html#_get_notation_indices_to_add',
                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation._notation_data_with_indices': ( 'markdown.obsidian.personal.machine_learning.notation.html#_notation_data_with_indices',
                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation.add_one_double_asts_to_line': ( 'markdown.obsidian.personal.machine_learning.notation.html#add_one_double_asts_to_line',
                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation.append_notation_data_to_database': ( 'markdown.obsidian.personal.machine_learning.notation.html#append_notation_data_to_database',
                                                                                                                                                                                 'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation.automatically_mark_notations': ( 'markdown.obsidian.personal.machine_learning.notation.html#automatically_mark_notations',
                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation.notation_data_from_note': ( 'markdown.obsidian.personal.machine_learning.notation.html#notation_data_from_note',
                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/notation.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.notation.notation_data_from_text': ( 'markdown.obsidian.personal.machine_learning.notation.html#notation_data_from_text',
                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/notation.py')},
            'trouver.markdown.obsidian.personal.machine_learning.notation_identification': { 'trouver.markdown.obsidian.personal.machine_learning.notation_identification._get_notation_indices_to_add': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#_get_notation_indices_to_add',
                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification._notation_data_with_indices': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#_notation_data_with_indices',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification.add_one_double_asts_to_line': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#add_one_double_asts_to_line',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification.append_notation_data_to_database': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#append_notation_data_to_database',
                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification.automatically_mark_notations': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#automatically_mark_notations',
                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification.notation_data_from_note': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#notation_data_from_note',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py'),
                                                                                             'trouver.markdown.obsidian.personal.machine_learning.notation_identification.notation_data_from_text': ( 'markdown.obsidian.personal.machine_learning.notation_identification.html#notation_data_from_text',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/notation_identification.py')},
            'trouver.markdown.obsidian.personal.machine_learning.notation_linking': { 'trouver.markdown.obsidian.personal.machine_learning.notation_linking._add_notation_link': ( 'markdown.obsidian.machine_learning.notation_linking.html#_add_notation_link',
                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._adjust_content': ( 'markdown.obsidian.machine_learning.notation_linking.html#_adjust_content',
                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._content_relied': ( 'markdown.obsidian.machine_learning.notation_linking.html#_content_relied',
                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._init_args_for_data_from_notation_notes': ( 'markdown.obsidian.machine_learning.notation_linking.html#_init_args_for_data_from_notation_notes',
                                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._linked_notat_note_names_from_content': ( 'markdown.obsidian.machine_learning.notation_linking.html#_linked_notat_note_names_from_content',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._linked_note_names_from_content': ( 'markdown.obsidian.machine_learning.notation_linking.html#_linked_note_names_from_content',
                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._notat_str': ( 'markdown.obsidian.machine_learning.notation_linking.html#_notat_str',
                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._origin_links_to_relied': ( 'markdown.obsidian.machine_learning.notation_linking.html#_origin_links_to_relied',
                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._origin_notation_note_already_has_link_to_relied': ( 'markdown.obsidian.machine_learning.notation_linking.html#_origin_notation_note_already_has_link_to_relied',
                                                                                                                                                                                                                 'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._positive_data_points': ( 'markdown.obsidian.machine_learning.notation_linking.html#_positive_data_points',
                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._positive_pairs_of_notation_notes': ( 'markdown.obsidian.machine_learning.notation_linking.html#_positive_pairs_of_notation_notes',
                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking._sample_data_points': ( 'markdown.obsidian.machine_learning.notation_linking.html#_sample_data_points',
                                                                                                                                                                                    'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.auto_add_link_to_notation_note': ( 'markdown.obsidian.machine_learning.notation_linking.html#auto_add_link_to_notation_note',
                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.auto_add_link_to_notation_note_via_data_point': ( 'markdown.obsidian.machine_learning.notation_linking.html#auto_add_link_to_notation_note_via_data_point',
                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.data_from_notation_notes': ( 'markdown.obsidian.machine_learning.notation_linking.html#data_from_notation_notes',
                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.data_points_for_reference': ( 'markdown.obsidian.machine_learning.notation_linking.html#data_points_for_reference',
                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.prediction_by_model': ( 'markdown.obsidian.machine_learning.notation_linking.html#prediction_by_model',
                                                                                                                                                                                    'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.prediction_by_model_via_datapoint': ( 'markdown.obsidian.machine_learning.notation_linking.html#prediction_by_model_via_datapoint',
                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py'),
                                                                                      'trouver.markdown.obsidian.personal.machine_learning.notation_linking.text_from_data_point': ( 'markdown.obsidian.machine_learning.notation_linking.html#text_from_data_point',
                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/notation_linking.py')},
            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization': { 'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._get_summary': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_get_summary',
                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._metadata_dict_has_auto_notation_summary_tag': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_metadata_dict_has_auto_notation_summary_tag',
                                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._notation_has_been_summarized': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_notation_has_been_summarized',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._notation_note_has_auto_summary_tag': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_notation_note_has_auto_summary_tag',
                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._summary_should_be_generated': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_summary_should_be_generated',
                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization._write_summary_to_notation_note': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#_write_summary_to_notation_note',
                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.append_column_for_single_text': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#append_column_for_single_text',
                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.append_summary_to_notation_note': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#append_summary_to_notation_note',
                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.append_to_notation_note_summarization_database': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#append_to_notation_note_summarization_database',
                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.gather_notation_note_summaries': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#gather_notation_note_summaries',
                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.get_latex_in_original_from_parsed_notation_note_data': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#get_latex_in_original_from_parsed_notation_note_data',
                                                                                                                                                                                                                                 'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.notation_summarization_data_from_note': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#notation_summarization_data_from_note',
                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.single_input_for_notation_summarization': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#single_input_for_notation_summarization',
                                                                                                                                                                                                                    'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py'),
                                                                                            'trouver.markdown.obsidian.personal.machine_learning.notation_summarization.summarize_notation': ( 'markdown.obsidian.personal.machine_learning.notation_summarization.html#summarize_notation',
                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/notation_summarization.py')},
            'trouver.markdown.obsidian.personal.machine_learning.notations': {},
            'trouver.markdown.obsidian.personal.machine_learning.note_division': { 'trouver.markdown.obsidian.personal.machine_learning.note_division.combine_info_notes_in_index_notes': ( 'markdown.obsidian.personal.machine_learning.note_division.html#combine_info_notes_in_index_notes',
                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/note_division.py')},
            'trouver.markdown.obsidian.personal.machine_learning.tokenize': { 'trouver.markdown.obsidian.personal.machine_learning.tokenize._add_nice_boxing_attrs_to_def_and_notat_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_add_nice_boxing_attrs_to_def_and_notat_tags',
                                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._append_to_pieces_start_and_end': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_append_to_pieces_start_and_end',
                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._char_is_in_seq': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_char_is_in_seq',
                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._collate_html_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_collate_html_tags',
                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._consolidate_token_preds': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_consolidate_token_preds',
                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._current_token_continues_the_previous_token': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_current_token_continues_the_previous_token',
                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._cutoff_notation_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_cutoff_notation_tag_data',
                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._divide_main_text': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_divide_main_text',
                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._divide_token_preds_into_parts': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_divide_token_preds_into_parts',
                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._extend_tag_data_ranges': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_extend_tag_data_ranges',
                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._find_places_to_divide_from_chunks': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_find_places_to_divide_from_chunks',
                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._format_main_text_and_add_html_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_format_main_text_and_add_html_tag_data',
                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._get_main_text_lines': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_get_main_text_lines',
                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._get_token_preds_by_dividing_main_text': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_get_token_preds_by_dividing_main_text',
                                                                                                                                                                                       'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._html_tag_data_from_part': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_html_tag_data_from_part',
                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._html_tag_from_double_ast': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_html_tag_from_double_ast',
                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._html_tags_from_token_preds': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_html_tags_from_token_preds',
                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._make_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_make_tag',
                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._min_max_char_ind_for_seq': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_min_max_char_ind_for_seq',
                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._no_overlap_with_previous_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_no_overlap_with_previous_tag_data',
                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._process_mf': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_process_mf',
                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._ranges_overlap': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_ranges_overlap',
                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._search_seq_ind_for_char': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_search_seq_ind_for_char',
                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._search_within_seq_for_char': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_search_within_seq_for_char',
                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._set_ner_ids_for_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_set_ner_ids_for_tag',
                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._start_end_seqs_indices_for_html_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_start_end_seqs_indices_for_html_tag',
                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize._write_text_with_html_tag_preds_to_note': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#_write_text_with_html_tag_preds_to_note',
                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.auto_mark_def_and_notats': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#auto_mark_def_and_notats',
                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.convert_double_asterisks_to_html_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#convert_double_asterisks_to_html_tags',
                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_preds_by_model': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#def_and_notat_preds_by_model',
                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_or_notat_from_html_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#def_or_notat_from_html_tag',
                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.html_data_from_note': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#html_data_from_note',
                                                                                                                                                                    'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.raw_text_with_html_tags_from_markdownfile': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#raw_text_with_html_tags_from_markdownfile',
                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize.py'),
                                                                              'trouver.markdown.obsidian.personal.machine_learning.tokenize.tokenize_html_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.html#tokenize_html_data',
                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize.py')},
            'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification': { 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._add_nice_boxing_attrs_to_def_and_notat_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_add_nice_boxing_attrs_to_def_and_notat_tags',
                                                                                                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._append_to_pieces_start_and_end': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_append_to_pieces_start_and_end',
                                                                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._char_is_in_seq': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_char_is_in_seq',
                                                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._collate_html_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_collate_html_tags',
                                                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._consolidate_token_preds': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_consolidate_token_preds',
                                                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._current_token_continues_the_previous_token': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_current_token_continues_the_previous_token',
                                                                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._cutoff_notation_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_cutoff_notation_tag_data',
                                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._divide_main_text': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_divide_main_text',
                                                                                                                                                                                                                                        'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._divide_token_preds_into_parts': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_divide_token_preds_into_parts',
                                                                                                                                                                                                                                                     'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._extend_tag_data_range_for_math_mode': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_extend_tag_data_range_for_math_mode',
                                                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._extend_tag_data_range_to_border_spaces': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_extend_tag_data_range_to_border_spaces',
                                                                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._extend_tag_data_ranges': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_extend_tag_data_ranges',
                                                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._extend_tag_data_ranges_to_balance_curly_braces': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_extend_tag_data_ranges_to_balance_curly_braces',
                                                                                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._find_places_to_divide_from_chunks': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_find_places_to_divide_from_chunks',
                                                                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._format_main_text_and_add_html_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_format_main_text_and_add_html_tag_data',
                                                                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._get_main_text_lines': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_get_main_text_lines',
                                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._get_token_preds_by_dividing_main_text': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_get_token_preds_by_dividing_main_text',
                                                                                                                                                                                                                                                             'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._html_tag_data_from_part': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_html_tag_data_from_part',
                                                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._html_tag_from_double_ast': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_html_tag_from_double_ast',
                                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._html_tags_from_token_preds': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_html_tags_from_token_preds',
                                                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._make_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_make_tag',
                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._min_max_char_ind_for_seq': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_min_max_char_ind_for_seq',
                                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._no_overlap_with_previous_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_no_overlap_with_previous_tag_data',
                                                                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._process_mf': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_process_mf',
                                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._ranges_overlap': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_ranges_overlap',
                                                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._search_seq_ind_for_char': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_search_seq_ind_for_char',
                                                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._search_within_seq_for_char': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_search_within_seq_for_char',
                                                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._set_ner_ids_for_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_set_ner_ids_for_tag',
                                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._start_end_seqs_indices_for_html_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_start_end_seqs_indices_for_html_tag',
                                                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._str_contains_latex_command_to_avoid': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_str_contains_latex_command_to_avoid',
                                                                                                                                                                                                                                                           'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._update_tag_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_update_tag_data',
                                                                                                                                                                                                                                       'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification._write_text_with_html_tag_preds_to_note': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#_write_text_with_html_tag_preds_to_note',
                                                                                                                                                                                                                                                              'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.auto_mark_def_and_notats': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#auto_mark_def_and_notats',
                                                                                                                                                                                                                                               'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.convert_double_asterisks_to_html_tags': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#convert_double_asterisks_to_html_tags',
                                                                                                                                                                                                                                                            'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.def_and_notat_preds_by_model': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#def_and_notat_preds_by_model',
                                                                                                                                                                                                                                                   'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.def_or_notat_from_html_tag': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#def_or_notat_from_html_tag',
                                                                                                                                                                                                                                                 'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html_data_from_note': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#html_data_from_note',
                                                                                                                                                                                                                                          'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.raw_text_with_html_tags_from_markdownfile': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#raw_text_with_html_tags_from_markdownfile',
                                                                                                                                                                                                                                                                'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py'),
                                                                                                                 'trouver.markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.tokenize_html_data': ( 'markdown.obsidian.personal.machine_learning.tokenize.def_and_notat_token_classification.html#tokenize_html_data',
                                                                                                                                                                                                                                         'trouver/markdown/obsidian/personal/machine_learning/tokenize/def_and_notat_token_classification.py')},
            'trouver.markdown.obsidian.personal.notation': { 'trouver.markdown.obsidian.personal.notation._build_replacables_from_groups': ( 'markdown.obsidian.personal.notation.html#_build_replacables_from_groups',
                                                                                                                                             'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._divide_bulleted_list_mf_at_end': ( 'markdown.obsidian.personal.notation.html#_divide_bulleted_list_mf_at_end',
                                                                                                                                              'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._full_notation_string': ( 'markdown.obsidian.personal.notation.html#_full_notation_string',
                                                                                                                                    'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._get_notation_string': ( 'markdown.obsidian.personal.notation.html#_get_notation_string',
                                                                                                                                   'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._latex_in_original_from_notat_notes_to_main_note': ( 'markdown.obsidian.personal.notation.html#_latex_in_original_from_notat_notes_to_main_note',
                                                                                                                                                               'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._latex_in_original_in_notat': ( 'markdown.obsidian.personal.notation.html#_latex_in_original_in_notat',
                                                                                                                                          'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._look_into_node': ( 'markdown.obsidian.personal.notation.html#_look_into_node',
                                                                                                                              'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._macro_is_actually_placeholder': ( 'markdown.obsidian.personal.notation.html#_macro_is_actually_placeholder',
                                                                                                                                             'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._main_of_notation_from_text': ( 'markdown.obsidian.personal.notation.html#_main_of_notation_from_text',
                                                                                                                                          'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._make_notat_notes_from_sifted_notats': ( 'markdown.obsidian.personal.notation.html#_make_notat_notes_from_sifted_notats',
                                                                                                                                                   'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._notat_str_and_linked_notat_note_name_from_bullet_point_part': ( 'markdown.obsidian.personal.notation.html#_notat_str_and_linked_notat_note_name_from_bullet_point_part',
                                                                                                                                                                           'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._notation_string_no_metadata': ( 'markdown.obsidian.personal.notation.html#_notation_string_no_metadata',
                                                                                                                                           'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._part_is_unordered_list_and_is_of_markdownstyle_link': ( 'markdown.obsidian.personal.notation.html#_part_is_unordered_list_and_is_of_markdownstyle_link',
                                                                                                                                                                   'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._raw_notation': ( 'markdown.obsidian.personal.notation.html#_raw_notation',
                                                                                                                            'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation._remove_the_notation_str_and_denotes_in_main_mf': ( 'markdown.obsidian.personal.notation.html#_remove_the_notation_str_and_denotes_in_main_mf',
                                                                                                                                                              'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.add_missing_notation_links_to_information_notes': ( 'markdown.obsidian.personal.notation.html#add_missing_notation_links_to_information_notes',
                                                                                                                                                              'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.add_notation_note_to_see_also': ( 'markdown.obsidian.personal.notation.html#add_notation_note_to_see_also',
                                                                                                                                            'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.index_notation_note_formatted_entry': ( 'markdown.obsidian.personal.notation.html#index_notation_note_formatted_entry',
                                                                                                                                                  'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.main_of_notation': ( 'markdown.obsidian.personal.notation.html#main_of_notation',
                                                                                                                               'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.make_a_notation_note': ( 'markdown.obsidian.personal.notation.html#make_a_notation_note',
                                                                                                                                   'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.make_notation_notes_from_HTML_tags': ( 'markdown.obsidian.personal.notation.html#make_notation_notes_from_html_tags',
                                                                                                                                                 'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.make_notation_notes_from_double_asts': ( 'markdown.obsidian.personal.notation.html#make_notation_notes_from_double_asts',
                                                                                                                                                   'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notat_str_from_doub_asts_in_std_info_note': ( 'markdown.obsidian.personal.notation.html#notat_str_from_doub_asts_in_std_info_note',
                                                                                                                                                        'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notat_str_from_html_tags': ( 'markdown.obsidian.personal.notation.html#notat_str_from_html_tags',
                                                                                                                                       'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notation_in_note': ( 'markdown.obsidian.personal.notation.html#notation_in_note',
                                                                                                                               'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notation_note_is_linked_in_see_also_section': ( 'markdown.obsidian.personal.notation.html#notation_note_is_linked_in_see_also_section',
                                                                                                                                                          'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notation_notes_linked_in_see_also_section': ( 'markdown.obsidian.personal.notation.html#notation_notes_linked_in_see_also_section',
                                                                                                                                                        'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notations_and_main_notes': ( 'markdown.obsidian.personal.notation.html#notations_and_main_notes',
                                                                                                                                       'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.notations_to_add_in_index': ( 'markdown.obsidian.personal.notation.html#notations_to_add_in_index',
                                                                                                                                        'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.parse_notation_note': ( 'markdown.obsidian.personal.notation.html#parse_notation_note',
                                                                                                                                  'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.regex_from_latex': ( 'markdown.obsidian.personal.notation.html#regex_from_latex',
                                                                                                                               'trouver/markdown/obsidian/personal/notation.py'),
                                                             'trouver.markdown.obsidian.personal.notation.regex_from_notation_note': ( 'markdown.obsidian.personal.notation.html#regex_from_notation_note',
                                                                                                                                       'trouver/markdown/obsidian/personal/notation.py')},
            'trouver.markdown.obsidian.personal.notation.in_standard_information_note': { 'trouver.markdown.obsidian.personal.notation.in_standard_information_note.add_missing_notation_links_to_information_notes': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#add_missing_notation_links_to_information_notes',
                                                                                                                                                                                                                        'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.add_notation_note_to_see_also': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#add_notation_note_to_see_also',
                                                                                                                                                                                                      'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.notat_str_from_doub_asts_in_std_info_note': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#notat_str_from_doub_asts_in_std_info_note',
                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.notat_str_from_html_tags': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#notat_str_from_html_tags',
                                                                                                                                                                                                 'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.notation_note_is_linked_in_see_also_section': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#notation_note_is_linked_in_see_also_section',
                                                                                                                                                                                                                    'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.notation_notes_linked_in_see_also_section': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#notation_notes_linked_in_see_also_section',
                                                                                                                                                                                                                  'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py'),
                                                                                          'trouver.markdown.obsidian.personal.notation.in_standard_information_note.notations_and_main_notes': ( 'markdown.obsidian.personal.notation.in_standard_information_note.html#notations_and_main_notes',
                                                                                                                                                                                                 'trouver/markdown/obsidian/personal/notation/in_standard_information_note.py')},
            'trouver.markdown.obsidian.personal.notation.parse': { 'trouver.markdown.obsidian.personal.notation.parse._divide_bulleted_list_mf_at_end': ( 'markdown.obsidian.personal.notation.parse.html#_divide_bulleted_list_mf_at_end',
                                                                                                                                                          'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse._get_notation_string': ( 'markdown.obsidian.personal.notation.parse.html#_get_notation_string',
                                                                                                                                               'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse._main_of_notation_from_text': ( 'markdown.obsidian.personal.notation.parse.html#_main_of_notation_from_text',
                                                                                                                                                      'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse._notat_str_and_linked_notat_note_name_from_bullet_point_part': ( 'markdown.obsidian.personal.notation.parse.html#_notat_str_and_linked_notat_note_name_from_bullet_point_part',
                                                                                                                                                                                       'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse._part_is_unordered_list_and_is_of_markdownstyle_link': ( 'markdown.obsidian.personal.notation.parse.html#_part_is_unordered_list_and_is_of_markdownstyle_link',
                                                                                                                                                                               'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse._remove_the_notation_str_and_denotes_in_main_mf': ( 'markdown.obsidian.personal.notation.parse.html#_remove_the_notation_str_and_denotes_in_main_mf',
                                                                                                                                                                          'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse.main_of_notation': ( 'markdown.obsidian.personal.notation.parse.html#main_of_notation',
                                                                                                                                           'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse.notation_in_note': ( 'markdown.obsidian.personal.notation.parse.html#notation_in_note',
                                                                                                                                           'trouver/markdown/obsidian/personal/notation/parse.py'),
                                                                   'trouver.markdown.obsidian.personal.notation.parse.parse_notation_note': ( 'markdown.obsidian.personal.notation.parse.html#parse_notation_note',
                                                                                                                                              'trouver/markdown/obsidian/personal/notation/parse.py')},
            'trouver.markdown.obsidian.personal.note_processing': { 'trouver.markdown.obsidian.personal.note_processing.process_standard_information_note': ( 'markdown.obsidian.personal.note_processing.html#process_standard_information_note',
                                                                                                                                                              'trouver/markdown/obsidian/personal/note_processing.py'),
                                                                    'trouver.markdown.obsidian.personal.note_processing.remove_double_asterisks_in_markdown_file': ( 'markdown.obsidian.personal.note_processing.html#remove_double_asterisks_in_markdown_file',
                                                                                                                                                                     'trouver/markdown/obsidian/personal/note_processing.py')},
            'trouver.markdown.obsidian.personal.note_type': { 'trouver.markdown.obsidian.personal.note_type.NoteTypeError': ( 'markdown.obsidian.personal.note_type.html#notetypeerror',
                                                                                                                              'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.NoteTypeError.__init__': ( 'markdown.obsidian.personal.note_type.html#notetypeerror.__init__',
                                                                                                                                       'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.PersonalNoteTypeEnum': ( 'markdown.obsidian.personal.note_type.html#personalnotetypeenum',
                                                                                                                                     'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.PersonalNoteTypeEnum.type_function': ( 'markdown.obsidian.personal.note_type.html#personalnotetypeenum.type_function',
                                                                                                                                                   'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_common_terms_note': ( 'markdown.obsidian.personal.note_type.html#_is_common_terms_note',
                                                                                                                                      'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_equation_note': ( 'markdown.obsidian.personal.note_type.html#_is_equation_note',
                                                                                                                                  'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_glossary_note': ( 'markdown.obsidian.personal.note_type.html#_is_glossary_note',
                                                                                                                                  'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_index_note': ( 'markdown.obsidian.personal.note_type.html#_is_index_note',
                                                                                                                               'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_index_of_notation_note': ( 'markdown.obsidian.personal.note_type.html#_is_index_of_notation_note',
                                                                                                                                           'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_mathematician_note': ( 'markdown.obsidian.personal.note_type.html#_is_mathematician_note',
                                                                                                                                       'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_notation_note': ( 'markdown.obsidian.personal.note_type.html#_is_notation_note',
                                                                                                                                  'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_notes_note': ( 'markdown.obsidian.personal.note_type.html#_is_notes_note',
                                                                                                                               'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_premise_note': ( 'markdown.obsidian.personal.note_type.html#_is_premise_note',
                                                                                                                                 'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_reference_note': ( 'markdown.obsidian.personal.note_type.html#_is_reference_note',
                                                                                                                                   'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_standard_information_note': ( 'markdown.obsidian.personal.note_type.html#_is_standard_information_note',
                                                                                                                                              'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type._is_template_note': ( 'markdown.obsidian.personal.note_type.html#_is_template_note',
                                                                                                                                  'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.assert_note_is_of_type': ( 'markdown.obsidian.personal.note_type.html#assert_note_is_of_type',
                                                                                                                                       'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.note_is_of_type': ( 'markdown.obsidian.personal.note_type.html#note_is_of_type',
                                                                                                                                'trouver/markdown/obsidian/personal/note_type.py'),
                                                              'trouver.markdown.obsidian.personal.note_type.type_of_note': ( 'markdown.obsidian.personal.note_type.html#type_of_note',
                                                                                                                             'trouver/markdown/obsidian/personal/note_type.py')},
            'trouver.markdown.obsidian.personal.notes': { 'trouver.markdown.obsidian.personal.notes.note_has_tag': ( 'markdown.obsidian.personal.notes.html#note_has_tag',
                                                                                                                     'trouver/markdown/obsidian/personal/notes.py'),
                                                          'trouver.markdown.obsidian.personal.notes.notes_linked_in_note': ( 'markdown.obsidian.personal.notes.html#notes_linked_in_note',
                                                                                                                             'trouver/markdown/obsidian/personal/notes.py'),
                                                          'trouver.markdown.obsidian.personal.notes.notes_linked_in_notes_linked_in_note': ( 'markdown.obsidian.personal.notes.html#notes_linked_in_notes_linked_in_note',
                                                                                                                                             'trouver/markdown/obsidian/personal/notes.py')},
            'trouver.markdown.obsidian.personal.reference': { 'trouver.markdown.obsidian.personal.reference._chapter_titles': ( 'markdown.obsidian.personal.reference.html#_chapter_titles',
                                                                                                                                'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._confirm_for_deletion': ( 'markdown.obsidian.personal.reference.html#_confirm_for_deletion',
                                                                                                                                      'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._create_template_note_at': ( 'markdown.obsidian.personal.reference.html#_create_template_note_at',
                                                                                                                                         'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._execute_deletion': ( 'markdown.obsidian.personal.reference.html#_execute_deletion',
                                                                                                                                  'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._files_in_reference_folder_via_glob': ( 'markdown.obsidian.personal.reference.html#_files_in_reference_folder_via_glob',
                                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._files_in_reference_folder_via_index_notes': ( 'markdown.obsidian.personal.reference.html#_files_in_reference_folder_via_index_notes',
                                                                                                                                                           'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._find_template_and_reference_notes': ( 'markdown.obsidian.personal.reference.html#_find_template_and_reference_notes',
                                                                                                                                                   'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._input_message': ( 'markdown.obsidian.personal.reference.html#_input_message',
                                                                                                                               'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_chapter_folders_and_indices': ( 'markdown.obsidian.personal.reference.html#_make_chapter_folders_and_indices',
                                                                                                                                                  'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_glossary_file': ( 'markdown.obsidian.personal.reference.html#_make_glossary_file',
                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_index_file': ( 'markdown.obsidian.personal.reference.html#_make_index_file',
                                                                                                                                 'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_notation_index_file': ( 'markdown.obsidian.personal.reference.html#_make_notation_index_file',
                                                                                                                                          'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_reference_file': ( 'markdown.obsidian.personal.reference.html#_make_reference_file',
                                                                                                                                     'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_reference_folder': ( 'markdown.obsidian.personal.reference.html#_make_reference_folder',
                                                                                                                                       'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_single_chapter_folders': ( 'markdown.obsidian.personal.reference.html#_make_single_chapter_folders',
                                                                                                                                             'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_single_chapter_index': ( 'markdown.obsidian.personal.reference.html#_make_single_chapter_index',
                                                                                                                                           'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_temp_folder': ( 'markdown.obsidian.personal.reference.html#_make_temp_folder',
                                                                                                                                  'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._make_template_file': ( 'markdown.obsidian.personal.reference.html#_make_template_file',
                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._manifest_template_file': ( 'markdown.obsidian.personal.reference.html#_manifest_template_file',
                                                                                                                                        'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._modify_fast_link_edit_and_templates': ( 'markdown.obsidian.personal.reference.html#_modify_fast_link_edit_and_templates',
                                                                                                                                                     'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference._obsidian_vault_plugin_configs_file': ( 'markdown.obsidian.personal.reference.html#_obsidian_vault_plugin_configs_file',
                                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.copy_obsidian_vault_configs': ( 'markdown.obsidian.personal.reference.html#copy_obsidian_vault_configs',
                                                                                                                                            'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.copy_obsidian_vault_configs_with_nice_modifications': ( 'markdown.obsidian.personal.reference.html#copy_obsidian_vault_configs_with_nice_modifications',
                                                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.delete_reference_folder': ( 'markdown.obsidian.personal.reference.html#delete_reference_folder',
                                                                                                                                        'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.files_in_reference_folder': ( 'markdown.obsidian.personal.reference.html#files_in_reference_folder',
                                                                                                                                          'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.get_index_notes_from_index_note': ( 'markdown.obsidian.personal.reference.html#get_index_notes_from_index_note',
                                                                                                                                                'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.get_index_notes_from_subdirectory': ( 'markdown.obsidian.personal.reference.html#get_index_notes_from_subdirectory',
                                                                                                                                                  'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.get_obsidian_vault_plugin_configs': ( 'markdown.obsidian.personal.reference.html#get_obsidian_vault_plugin_configs',
                                                                                                                                                  'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.index_note_for_reference': ( 'markdown.obsidian.personal.reference.html#index_note_for_reference',
                                                                                                                                         'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.modify_obsidian_vault_plugin_configs': ( 'markdown.obsidian.personal.reference.html#modify_obsidian_vault_plugin_configs',
                                                                                                                                                     'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.reference_directory': ( 'markdown.obsidian.personal.reference.html#reference_directory',
                                                                                                                                    'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.reference_folders_in_vault': ( 'markdown.obsidian.personal.reference.html#reference_folders_in_vault',
                                                                                                                                           'trouver/markdown/obsidian/personal/reference.py'),
                                                              'trouver.markdown.obsidian.personal.reference.setup_folder_for_new_reference': ( 'markdown.obsidian.personal.reference.html#setup_folder_for_new_reference',
                                                                                                                                               'trouver/markdown/obsidian/personal/reference.py')},
            'trouver.markdown.obsidian.personal.vault': { 'trouver.markdown.obsidian.personal.vault._setup_alphabetical_subdirectories': ( 'markdown.obsidian.personal.vault.html#_setup_alphabetical_subdirectories',
                                                                                                                                           'trouver/markdown/obsidian/personal/vault.py'),
                                                          'trouver.markdown.obsidian.personal.vault._setup_trouver_vault_essentials': ( 'markdown.obsidian.personal.vault.html#_setup_trouver_vault_essentials',
                                                                                                                                        'trouver/markdown/obsidian/personal/vault.py'),
                                                          'trouver.markdown.obsidian.personal.vault.setup_obsidian_vault_for_trouver': ( 'markdown.obsidian.personal.vault.html#setup_obsidian_vault_for_trouver',
                                                                                                                                         'trouver/markdown/obsidian/personal/vault.py')},
            'trouver.markdown.obsidian.tags': { 'trouver.markdown.obsidian.tags.strip_auto_from_tag': ( 'markdown.obsidian.tags.html#strip_auto_from_tag',
                                                                                                        'trouver/markdown/obsidian/tags.py'),
                                                'trouver.markdown.obsidian.tags.tag_is_auto_tag': ( 'markdown.obsidian.tags.html#tag_is_auto_tag',
                                                                                                    'trouver/markdown/obsidian/tags.py'),
                                                'trouver.markdown.obsidian.tags.tag_without_hashtag': ( 'markdown.obsidian.tags.html#tag_without_hashtag',
                                                                                                        'trouver/markdown/obsidian/tags.py'),
                                                'trouver.markdown.obsidian.tags.to_tag_str': ( 'markdown.obsidian.tags.html#to_tag_str',
                                                                                               'trouver/markdown/obsidian/tags.py')},
            'trouver.markdown.obsidian.vault': { 'trouver.markdown.obsidian.vault.NoteDoesNotExistError': ( 'markdown.obsidian.vault.html#notedoesnotexisterror',
                                                                                                            'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteDoesNotExistError.__init__': ( 'markdown.obsidian.vault.html#notedoesnotexisterror.__init__',
                                                                                                                     'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteDoesNotExistError.from_note_name': ( 'markdown.obsidian.vault.html#notedoesnotexisterror.from_note_name',
                                                                                                                           'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotFoundInCacheError': ( 'markdown.obsidian.vault.html#notenotfoundincacheerror',
                                                                                                               'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotFoundInCacheError.__init__': ( 'markdown.obsidian.vault.html#notenotfoundincacheerror.__init__',
                                                                                                                        'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotFoundInCacheError.from_note_name': ( 'markdown.obsidian.vault.html#notenotfoundincacheerror.from_note_name',
                                                                                                                              'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotUniqueError': ( 'markdown.obsidian.vault.html#notenotuniqueerror',
                                                                                                         'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotUniqueError.__init__': ( 'markdown.obsidian.vault.html#notenotuniqueerror.__init__',
                                                                                                                  'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NoteNotUniqueError.from_note_names': ( 'markdown.obsidian.vault.html#notenotuniqueerror.from_note_names',
                                                                                                                         'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NotePathIsNotIdentifiedError': ( 'markdown.obsidian.vault.html#notepathisnotidentifiederror',
                                                                                                                   'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NotePathIsNotIdentifiedError.__init__': ( 'markdown.obsidian.vault.html#notepathisnotidentifiederror.__init__',
                                                                                                                            'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.NotePathIsNotIdentifiedError.from_note': ( 'markdown.obsidian.vault.html#notepathisnotidentifiederror.from_note',
                                                                                                                             'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote': ( 'markdown.obsidian.vault.html#vaultnote',
                                                                                                'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.__init__': ( 'markdown.obsidian.vault.html#vaultnote.__init__',
                                                                                                         'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._add_single_entry_to_cache': ( 'markdown.obsidian.vault.html#vaultnote._add_single_entry_to_cache',
                                                                                                                           'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._check_if_cache_needs_to_update': ( 'markdown.obsidian.vault.html#vaultnote._check_if_cache_needs_to_update',
                                                                                                                                'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._check_name_exists_and_unique_in_vault_cache': ( 'markdown.obsidian.vault.html#vaultnote._check_name_exists_and_unique_in_vault_cache',
                                                                                                                                             'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._get_from_cache': ( 'markdown.obsidian.vault.html#vaultnote._get_from_cache',
                                                                                                                'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._identify_rel_path': ( 'markdown.obsidian.vault.html#vaultnote._identify_rel_path',
                                                                                                                   'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote._remove_single_entry_from_cache': ( 'markdown.obsidian.vault.html#vaultnote._remove_single_entry_from_cache',
                                                                                                                                'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.clear_cache': ( 'markdown.obsidian.vault.html#vaultnote.clear_cache',
                                                                                                            'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.create': ( 'markdown.obsidian.vault.html#vaultnote.create',
                                                                                                       'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.delete': ( 'markdown.obsidian.vault.html#vaultnote.delete',
                                                                                                       'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.directory': ( 'markdown.obsidian.vault.html#vaultnote.directory',
                                                                                                          'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.exists': ( 'markdown.obsidian.vault.html#vaultnote.exists',
                                                                                                       'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.identify_rel_path': ( 'markdown.obsidian.vault.html#vaultnote.identify_rel_path',
                                                                                                                  'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.move_to': ( 'markdown.obsidian.vault.html#vaultnote.move_to',
                                                                                                        'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.move_to_folder': ( 'markdown.obsidian.vault.html#vaultnote.move_to_folder',
                                                                                                               'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.obsidian_identifier': ( 'markdown.obsidian.vault.html#vaultnote.obsidian_identifier',
                                                                                                                    'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.path': ( 'markdown.obsidian.vault.html#vaultnote.path',
                                                                                                     'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.rel_path_identified': ( 'markdown.obsidian.vault.html#vaultnote.rel_path_identified',
                                                                                                                    'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.rename': ( 'markdown.obsidian.vault.html#vaultnote.rename',
                                                                                                       'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.text': ( 'markdown.obsidian.vault.html#vaultnote.text',
                                                                                                     'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.unique_name': ( 'markdown.obsidian.vault.html#vaultnote.unique_name',
                                                                                                            'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.VaultNote.update_cache': ( 'markdown.obsidian.vault.html#vaultnote.update_cache',
                                                                                                             'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.all_note_paths_by_name': ( 'markdown.obsidian.vault.html#all_note_paths_by_name',
                                                                                                             'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.all_paths_to_notes_in_vault': ( 'markdown.obsidian.vault.html#all_paths_to_notes_in_vault',
                                                                                                                  'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.note_name_from_path': ( 'markdown.obsidian.vault.html#note_name_from_path',
                                                                                                          'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.note_name_unique': ( 'markdown.obsidian.vault.html#note_name_unique',
                                                                                                       'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.note_path_by_name': ( 'markdown.obsidian.vault.html#note_path_by_name',
                                                                                                        'trouver/markdown/obsidian/vault.py'),
                                                 'trouver.markdown.obsidian.vault.path_to_obs_id': ( 'markdown.obsidian.vault.html#path_to_obs_id',
                                                                                                     'trouver/markdown/obsidian/vault.py')},
            'trouver.markdown.obsidian.vault_and_links': { 'trouver.markdown.obsidian.vault_and_links._custom_text_for_links_in_text': ( 'markdown.obsidian.vault_and_links.html#_custom_text_for_links_in_text',
                                                                                                                                         'trouver/markdown/obsidian/vault_and_links.py'),
                                                           'trouver.markdown.obsidian.vault_and_links.all_custom_text_for_links_in_vault': ( 'markdown.obsidian.vault_and_links.html#all_custom_text_for_links_in_vault',
                                                                                                                                             'trouver/markdown/obsidian/vault_and_links.py'),
                                                           'trouver.markdown.obsidian.vault_and_links.all_links_in_vault': ( 'markdown.obsidian.vault_and_links.html#all_links_in_vault',
                                                                                                                             'trouver/markdown/obsidian/vault_and_links.py')},
            'trouver.trouver.markdown.obsidian.vault_and_links': { 'trouver.trouver.markdown.obsidian.vault_and_links._custom_text_for_links_in_text': ( 'markdown.obsidian.vault_and_links.html#_custom_text_for_links_in_text',
                                                                                                                                                         'trouver/trouver/markdown/obsidian/vault_and_links.py'),
                                                                   'trouver.trouver.markdown.obsidian.vault_and_links.all_custom_text_for_links_in_vault': ( 'markdown.obsidian.vault_and_links.html#all_custom_text_for_links_in_vault',
                                                                                                                                                             'trouver/trouver/markdown/obsidian/vault_and_links.py'),
                                                                   'trouver.trouver.markdown.obsidian.vault_and_links.all_links_in_vault': ( 'markdown.obsidian.vault_and_links.html#all_links_in_vault',
                                                                                                                                             'trouver/trouver/markdown/obsidian/vault_and_links.py')},
            'trouver.tutorial.concise_code': {}}}
